---
name: Feature Request
about: Guideline for requesting HangoutCore Features.
title: "[Feature]"
labels: Feature Request
assignees: ''

---

- [ ] I have verified this feature does not currently exist.
### Reason for request:
*Short summary as to why you believe this feature would benefit HangoutCore Users.*

# Features:
###### Feature Category:
- [ ] **Feature Name**:
- *Feature Description...*
